package com.artfess.yhxt.statistics.dao;

import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author zhx
 * @create 2021/11/2
 */
public interface WorkbenchDao {
    Integer selectSiteCount(@Param("userId") String userId);

    Integer selectDiseaseCount(@Param("userId") String userId);

    //即将逾期养护工单
    Long selectWorkOrderOverdueCount(@Param("currentOrgId") String currentOrgId);

    //已逾期养护工单
    Long workOrderOverdueCountTrue(@Param("currentOrgId") String currentOrgId);

    Long selectDiseaseOverdueCount(@Param("currentOrgId") String currentOrgId);

    Long selectDiseaseOverdueCountTrue(@Param("currentOrgId") String currentOrgId);

    //桥梁定期
    Long brideOneCount(@Param("ids") List<String> currentOrgId);

    Long brideThreeCount(@Param("ids") List<String> currentOrgId);

    Long culvertCount(@Param("ids") List<String> currentOrgId);

    Long tunnelCount(@Param("ids") List<String> currentOrgId);

    Long sideSlopeCount(@Param("ids") List<String> currentOrgId);

    List<String> brideOneOftenCount(@Param("ids") List<String> ids);

    List<String> brideTwoOftenCount(@Param("ids") List<String> ids);

    List<String> brideThreeOftenCount(@Param("ids") List<String> ids);

    List<String> culvertOftenCount(@Param("ids") List<String> currentOrgId);

    List<String> tunnelOneOftenCount(@Param("ids") List<String> currentOrgId);

    List<String> tunnelTwoOftenCount(@Param("ids") List<String> currentOrgId);

    List<String> tunnelThreeOftenCount(@Param("ids") List<String> currentOrgId);

    List<String> sideSlopeOftenCount(@Param("ids") List<String> currentOrgId);
}
